.. _cookiecutters:

Pyramid cookiecutters
=====================
A :term:`cookiecutter` is a command-line utility that creates projects from :ref:`cookiecutters <cookiecutter:readme>` (project templates).

The Pyramid cookiecutter replaced the deprecated Pyramid scaffolds, and should be used going forward.

`pyramid-cookiecutter-starter <https://github.com/Pylons/pyramid-cookiecutter-starter>`_

.. versionadded:: 1.8
    Added cookiecutter support.

.. deprecated:: 1.8
    Scaffolds may be removed in a future version of Pyramid.

.. versionchanged:: 1.10
    Merged features from ``pyramid-cookiecutter-alchemy`` and ``pyramid-cookiecutter-zodb`` into the single cookiecutter to rule them all, ``pyramid-cookiecutter-starter``.

.. deprecated:: 1.10
    ``pyramid-cookiecutter-alchemy`` and ``pyramid-cookiecutter-zodb`` are no longer supported.
    Use ``pyramid-cookiecutter-starter`` going forward.

.. seealso::

    See also `Cookiecutter Installation <https://cookiecutter.readthedocs.io/en/latest/installation.html>`_ and `Cookiecutter Features <https://cookiecutter.readthedocs.io/en/latest/readme.html#features>`_. Development of cookiecutters is documented under `Learn the Basics of Cookiecutter by Creating a Cookiecutter <https://cookiecutter.readthedocs.io/en/latest/first_steps.html>`_.

.. seealso::

    See also :term:`scaffold`.
